import React from 'react';
import { PropsWithMetadata, Theme } from '@highlight-ui/utils-commons';
export declare type ButtonRef = React.Ref<HTMLAnchorElement | HTMLButtonElement>;
export declare type ButtonProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Makes the component to render an anchor tag instead of the button. Affects the set props that can be provided */
    actAsAnchor?: boolean;
    /** Determines whether the button should have an active state */
    active?: boolean;
    /** Makes the component behave as a block element (take up the whole available space) */
    block?: boolean;
    /** Allows providing a custom class name */
    className?: string;
    /** Marks the button as disabled */
    disabled?: boolean;
    /** Allows to provide an icon by icon's name */
    icon?: string;
    /** Makes the button to render a loading spinner additionally to the label */
    loading?: boolean;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler;
    /** Determines whether to render the outline for the button or not */
    outline?: boolean;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties;
    /** Tab index HTML property */
    tabIndex?: number;
    /** Allows specifying the styling of the button */
    theme?: Theme;
    /** Button Type HTML property */
    type?: 'button' | 'submit' | 'reset';
}>> & (React.ComponentPropsWithoutRef<'a'> | React.ComponentPropsWithoutRef<'button'>);
declare const Button: React.ForwardRefExoticComponent<ButtonProps & React.RefAttributes<HTMLAnchorElement | HTMLButtonElement>>;
export default Button;
